.. :changelog:

Release History
===============

0.1.1 (2018-03-07)
~~~~~~~~~~~~~~~~~~

**Improvements**

- Added `logging` and `verboselogs` logging.
- Replaced all `if verbose: print('...')` with `logger.verbose('...')` calls.


0.1.0 (2018-03-07)
~~~~~~~~~~~~~~~~~~

- Initial public release.